from astropy import units as u
import numpy as np
from matplotlib import pyplot as plt
from spectacle.modeling import Spectral1D, OpticalDepth1D
from spectacle.fitting.line_finder import LineFinder1D
line1 = OpticalDepth1D("HI1216", v_doppler=10 * u.km/u.s, column_density=14, delta_v=15 * u.km/u.s)
line2 = OpticalDepth1D("HI1216", v_doppler=70 * u.km/u.s, column_density=15)
spec_mod = Spectral1D([line1, line2], continuum=0, output='optical_depth')
x = np.linspace(-200, 200, 1000) * u.Unit('km/s')
y = spec_mod(x)

line_finder = LineFinder1D(ions=["HI1216"], continuum=0, output='optical_depth')
finder_spec_mod = line_finder(x, y)
f, ax = plt.subplots()  # doctest: +SKIP
ax.step(x, y, label="Original Data") # doctest: +SKIP
ax.step(x, finder_spec_mod(x), label="Finder Result") # doctest: +SKIP
ax.set_xlabel("Velocity [km/s]")  # doctest: +SKIP
f.legend()  # doctest: +SKIP
