from astropy import units as u
import numpy as np
from matplotlib import pyplot as plt
from spectacle.modeling import Spectral1D, OpticalDepth1D

line1 = OpticalDepth1D("HI1216", v_doppler=500 * u.km/u.s, column_density=14)
line2 = OpticalDepth1D("OVI1032", v_doppler=500 * u.km/u.s, column_density=15)

# LSFs can either be applied directly during spectrum model creation:

spec_mod_with_lsf = Spectral1D([line1, line2], continuum=1, lsf='cos', output='flux')

# or they can be applied after the fact:

spec_mod = Spectral1D([line1, line2], continuum=1, output='flux')
spec_mod_with_lsf = spec_mod.with_lsf('cos')

x = np.linspace(1000, 1300, 1000) * u.Unit('Angstrom')

f, ax = plt.subplots()
ax.step(x, spec_mod(x), label="Flux") # doctest: +IGNORE_OUTPUT
ax.step(x, spec_mod_with_lsf(x), label="Flux with LSF") # doctest: +IGNORE_OUTPUT
ax.set_xlabel("Wavelength [Angstrom]")  # doctest: +IGNORE_OUTPUT
f.legend(loc=0)  # doctest: +IGNORE_OUTPUT
